@@ -1,5 +1,6 @@
 from __future__ import unicode_literals
 
+from collections import defaultdict
 import json
 import logging
 
@@ -37,6 +38,13 @@ class Index:
         self.fields = attrs['fields']
         self.pipeline = attrs['pipeline']
 
+    def __eq__(self, other):
+        # TODO: extend equality to other attributes
+        return (
+            self.inverted_index == other.inverted_index and
+            self.fields == other.fields
+        )
+
     def search(self, query_string):
         """Performs a search against the index using lunr query syntax.
 
@@ -118,7 +126,7 @@ class Index:
         query_vectors = {field: Vector() for field in self.fields}
         term_field_cache = {}
         required_matches = {}
-        prohibited_matches = {}
+        prohibited_matches = defaultdict(set)
 
         for clause in query.clauses:
             # Unless the pipeline has been disabled for this term, which is
@@ -191,9 +199,6 @@ class Index:
                         # set of prohibited matches for this field, creating
                         # that set if it does not exist yet.
                         elif clause.presence == QueryPresence.PROHIBITED:
-                            if field not in prohibited_matches:
-                                prohibited_matches[field] = set()
-
                             prohibited_matches[field] = (
                                 prohibited_matches[field].union(
                                     matching_documents_set))
@@ -211,10 +216,7 @@ class Index:
                         # in the vector for the term we are working with.
                         # In that case we just add the scores together.
                         query_vectors[field].upsert(
-                            term_index,
-                            1 * clause.boost,
-                            lambda a, b: a + b
-                        )
+                            term_index, clause.boost, lambda a, b: a + b)
 
                         # If we've already seen this term, field combo then
                         # we've already collected the matching documents and
